@@ -4,7 +4,7 @@ import json
 
 from parameterized import parameterized
 
-from converters.logic.converter_logic.envidat_to_datacite import EnviDatToDataCite
+from envidat_converters.logic.converter_logic.envidat_to_datacite import EnviDatToDataCite
 
 if __name__ == "__main__":
     unittest.main()
