@@ -2,7 +2,7 @@ import unittest
 import json
 
 from parameterized import parameterized
-from converters.logic.converter_logic.envidat_to_jsonld import EnviDatToJsonLD
+from envidat_converters.logic.converter_logic.envidat_to_jsonld import EnviDatToJsonLD
 
 if __name__ == "__main__":
     unittest.main()
