@@ -2,7 +2,7 @@ import unittest
 import json
 
 from parameterized import parameterized
-from converters.logic.converter_logic.envidat_to_signposting import EnviDatToSignposting
+from envidat_converters.logic.converter_logic.envidat_to_signposting import EnviDatToSignposting
 
 if __name__ == "__main__":
     unittest.main()
